@@ -4,7 +4,7 @@
 from __future__ import unicode_literals
 import sys
 import json
-import string
+import string as pystring
 from collections import defaultdict
 
 from .packages import nltk
@@ -21,6 +21,7 @@ from .sentiments import BaseSentimentAnalyzer, PatternAnalyzer
 from .parsers import BaseParser, PatternParser
 from .translate import Translator
 from .en import suggest
+from .exceptions import MissingCorpusException
 
 
 class Word(unicode):
@@ -91,6 +92,16 @@ class Word(unicode):
         '''
         return Word(self.spellcheck()[0][0])
 
+    @cached_property
+    def lemma(self):
+        '''Return the lemma for a word using WordNet's morphy function.'''
+        lemmatizer = nltk.stem.WordNetLemmatizer()
+        try:
+            return lemmatizer.lemmatize(self.string)
+        except LookupError as err:
+            print(err)
+            raise MissingCorpusException()
+
 
 class WordList(list):
 
@@ -167,11 +178,15 @@ class WordList(list):
 
     def singularize(self):
         '''Return the single version of each word in this WordList.'''
-        return [word.singularize() for word in self]
+        return self.__class__([word.singularize() for word in self])
 
     def pluralize(self):
         '''Return the plural version of each word in this WordList.'''
-        return [word.pluralize() for word in self]
+        return self.__class__([word.pluralize() for word in self])
+
+    def lemmatize(self):
+        '''Return the lemma of each word in this WordList.'''
+        return self.__class__([word.lemma for word in self])
 
 def _validated_param(obj, name, base_class, default, base_class_name=None):
     '''Validates a parameter passed to __init__. Makes sure that obj is
@@ -285,6 +300,7 @@ class BaseBlob(ComparableMixin):
         return p.parse(self.raw)
 
     def classify(self):
+        '''Classify the blob using the blob's ``classifier``.'''
         if self.classifier is None:
             raise NameError("This blob has no classfier. Train one first!")
         return self.classifier.classify(self.raw)
@@ -435,7 +451,7 @@ class BaseBlob(ComparableMixin):
         ret = ''
         for i, word in enumerate(corrected):
             # Avoid an extra space at the beginning
-            if word in string.punctuation or i == 0:
+            if word in pystring.punctuation or i == 0:
                 ret = ''.join([ret, word])
             else:
                 ret = ' '.join([ret, word])
@@ -747,7 +763,8 @@ class Blobber(object):
 
     def __init__(self, tokenizer=None, pos_tagger=None, np_extractor=None,
                 analyzer=None, parser=None, classifier=None):
-        _initialize_models(self, tokenizer, pos_tagger, np_extractor, analyzer, parser, classifier)
+        _initialize_models(self, tokenizer, pos_tagger, np_extractor, analyzer,
+                            parser, classifier)
 
     def __call__(self, text):
         '''Return a new TextBlob object with this Blobber's ``np_extractor``,
